@@ -173,8 +173,8 @@ def check_python_version():
 
 
 def get_file_size(path_to_file):
-    if Path(etld_lib_config.kb_cve_qid_file).is_file():
-       return Path(etld_lib_config.kb_cve_qid_file).stat().st_size
+    if Path(path_to_file).is_file():
+       return Path(path_to_file).stat().st_size
 
 
 def dbm_type_message(dbm_file):
