@@ -223,7 +223,7 @@ def test_command_line_arguments():
     # If no options check for -u.  If -u exists, help_message.  If -u does not exist, continue to new user prompts.
     # If -u is not set, help_message
     if results.qetl_user_home_dir is None:
-        help_message(f"Please enter -u [ your opt/qetl/users/ user home directory path ]\n\n"
+        help_message(f"Please enter -u [ your /opt/qetl/users/ user home directory path ]\n\n"
                      f"    Note: /opt/qetl/users/newuser is the root directory for your qetl userhome directory,\n" 
                      f"           enter a new path including the opt/qetl/users/newuser \n"
                      f"           in the path you have authorization to write to.\n"
